==> iam-0.10.0-sources.jar: software/amazon/awscdk/services/iam/cloudformation/GroupResourceProps.java <==
package software.amazon.awscdk.services.iam.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:43:13.434Z")
public interface GroupResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::IAM::Group.GroupName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
     */
    java.lang.Object getGroupName();
    /**
     * ``AWS::IAM::Group.GroupName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
     */
    void setGroupName(final java.lang.String value);
    /**
     * ``AWS::IAM::Group.GroupName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
     */
    void setGroupName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::IAM::Group.ManagedPolicyArns``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
     */
    java.lang.Object getManagedPolicyArns();
    /**
     * ``AWS::IAM::Group.ManagedPolicyArns``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
     */
    void setManagedPolicyArns(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::IAM::Group.ManagedPolicyArns``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
     */
    void setManagedPolicyArns(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::IAM::Group.Path``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
     */
    java.lang.Object getPath();
    /**
     * ``AWS::IAM::Group.Path``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
     */
    void setPath(final java.lang.String value);
    /**
     * ``AWS::IAM::Group.Path``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
     */
    void setPath(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::IAM::Group.Policies``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
     */
    java.lang.Object getPolicies();
    /**
     * ``AWS::IAM::Group.Policies``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
     */
    void setPolicies(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::IAM::Group.Policies``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
     */
    void setPolicies(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link GroupResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link GroupResourceProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _groupName;
        @javax.annotation.Nullable
        private java.lang.Object _managedPolicyArns;
        @javax.annotation.Nullable
        private java.lang.Object _path;
        @javax.annotation.Nullable
        private java.lang.Object _policies;

        /**
         * Sets the value of GroupName
         * @param value ``AWS::IAM::Group.GroupName``
         * @return {@code this}
         */
        public Builder withGroupName(@javax.annotation.Nullable final java.lang.String value) {
            this._groupName = value;
            return this;
        }
        /**
         * Sets the value of GroupName
         * @param value ``AWS::IAM::Group.GroupName``
         * @return {@code this}
         */
        public Builder withGroupName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._groupName = value;
            return this;
        }
        /**
         * Sets the value of ManagedPolicyArns
         * @param value ``AWS::IAM::Group.ManagedPolicyArns``
         * @return {@code this}
         */
        public Builder withManagedPolicyArns(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._managedPolicyArns = value;
            return this;
        }
        /**
         * Sets the value of ManagedPolicyArns
         * @param value ``AWS::IAM::Group.ManagedPolicyArns``
         * @return {@code this}
         */
        public Builder withManagedPolicyArns(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._managedPolicyArns = value;
            return this;
        }
        /**
         * Sets the value of Path
         * @param value ``AWS::IAM::Group.Path``
         * @return {@code this}
         */
        public Builder withPath(@javax.annotation.Nullable final java.lang.String value) {
            this._path = value;
            return this;
        }
        /**
         * Sets the value of Path
         * @param value ``AWS::IAM::Group.Path``
         * @return {@code this}
         */
        public Builder withPath(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._path = value;
            return this;
        }
        /**
         * Sets the value of Policies
         * @param value ``AWS::IAM::Group.Policies``
         * @return {@code this}
         */
        public Builder withPolicies(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._policies = value;
            return this;
        }
        /**
         * Sets the value of Policies
         * @param value ``AWS::IAM::Group.Policies``
         * @return {@code this}
         */
        public Builder withPolicies(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._policies = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GroupResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public GroupResourceProps build() {
            return new GroupResourceProps() {
                @javax.annotation.Nullable
                private java.lang.Object $groupName = _groupName;
                @javax.annotation.Nullable
                private java.lang.Object $managedPolicyArns = _managedPolicyArns;
                @javax.annotation.Nullable
                private java.lang.Object $path = _path;
                @javax.annotation.Nullable
                private java.lang.Object $policies = _policies;

                @Override
                public java.lang.Object getGroupName() {
                    return this.$groupName;
                }

                @Override
                public void setGroupName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$groupName = value;
                }

                @Override
                public void setGroupName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$groupName = value;
                }

                @Override
                public java.lang.Object getManagedPolicyArns() {
                    return this.$managedPolicyArns;
                }

                @Override
                public void setManagedPolicyArns(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$managedPolicyArns = value;
                }

                @Override
                public void setManagedPolicyArns(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$managedPolicyArns = value;
                }

                @Override
                public java.lang.Object getPath() {
                    return this.$path;
                }

                @Override
                public void setPath(@javax.annotation.Nullable final java.lang.String value) {
                    this.$path = value;
                }

                @Override
                public void setPath(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$path = value;
                }

                @Override
                public java.lang.Object getPolicies() {
                    return this.$policies;
                }

                @Override
                public void setPolicies(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$policies = value;
                }

                @Override
                public void setPolicies(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$policies = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.iam.cloudformation.GroupResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::IAM::Group.GroupName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getGroupName() {
            return this.jsiiGet("groupName", java.lang.Object.class);
        }

        /**
         * ``AWS::IAM::Group.GroupName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
         */
        @Override
        public void setGroupName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("groupName", value);
        }

        /**
         * ``AWS::IAM::Group.GroupName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
         */
        @Override
        public void setGroupName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("groupName", value);
        }

        /**
         * ``AWS::IAM::Group.ManagedPolicyArns``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getManagedPolicyArns() {
            return this.jsiiGet("managedPolicyArns", java.lang.Object.class);
        }

        /**
         * ``AWS::IAM::Group.ManagedPolicyArns``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
         */
        @Override
        public void setManagedPolicyArns(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("managedPolicyArns", value);
        }

        /**
         * ``AWS::IAM::Group.ManagedPolicyArns``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
         */
        @Override
        public void setManagedPolicyArns(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("managedPolicyArns", value);
        }

        /**
         * ``AWS::IAM::Group.Path``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getPath() {
            return this.jsiiGet("path", java.lang.Object.class);
        }

        /**
         * ``AWS::IAM::Group.Path``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
         */
        @Override
        public void setPath(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("path", value);
        }

        /**
         * ``AWS::IAM::Group.Path``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
         */
        @Override
        public void setPath(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("path", value);
        }

        /**
         * ``AWS::IAM::Group.Policies``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getPolicies() {
            return this.jsiiGet("policies", java.lang.Object.class);
        }

        /**
         * ``AWS::IAM::Group.Policies``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
         */
        @Override
        public void setPolicies(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("policies", value);
        }

        /**
         * ``AWS::IAM::Group.Policies``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
         */
        @Override
        public void setPolicies(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("policies", value);
        }
    }
}

==> iam-0.12.0-sources.jar: software/amazon/awscdk/services/iam/cloudformation/GroupResourceProps.java <==
package software.amazon.awscdk.services.iam.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-12T09:51:09.211Z")
public interface GroupResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::IAM::Group.GroupName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
     */
    java.lang.Object getGroupName();
    /**
     * ``AWS::IAM::Group.GroupName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
     */
    void setGroupName(final java.lang.String value);
    /**
     * ``AWS::IAM::Group.GroupName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
     */
    void setGroupName(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::IAM::Group.ManagedPolicyArns``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
     */
    java.lang.Object getManagedPolicyArns();
    /**
     * ``AWS::IAM::Group.ManagedPolicyArns``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
     */
    void setManagedPolicyArns(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::IAM::Group.ManagedPolicyArns``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
     */
    void setManagedPolicyArns(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::IAM::Group.Path``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
     */
    java.lang.Object getPath();
    /**
     * ``AWS::IAM::Group.Path``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
     */
    void setPath(final java.lang.String value);
    /**
     * ``AWS::IAM::Group.Path``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
     */
    void setPath(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::IAM::Group.Policies``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
     */
    java.lang.Object getPolicies();
    /**
     * ``AWS::IAM::Group.Policies``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
     */
    void setPolicies(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::IAM::Group.Policies``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
     */
    void setPolicies(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link GroupResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link GroupResourceProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _groupName;
        @javax.annotation.Nullable
        private java.lang.Object _managedPolicyArns;
        @javax.annotation.Nullable
        private java.lang.Object _path;
        @javax.annotation.Nullable
        private java.lang.Object _policies;

        /**
         * Sets the value of GroupName
         * @param value ``AWS::IAM::Group.GroupName``
         * @return {@code this}
         */
        public Builder withGroupName(@javax.annotation.Nullable final java.lang.String value) {
            this._groupName = value;
            return this;
        }
        /**
         * Sets the value of GroupName
         * @param value ``AWS::IAM::Group.GroupName``
         * @return {@code this}
         */
        public Builder withGroupName(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._groupName = value;
            return this;
        }
        /**
         * Sets the value of ManagedPolicyArns
         * @param value ``AWS::IAM::Group.ManagedPolicyArns``
         * @return {@code this}
         */
        public Builder withManagedPolicyArns(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._managedPolicyArns = value;
            return this;
        }
        /**
         * Sets the value of ManagedPolicyArns
         * @param value ``AWS::IAM::Group.ManagedPolicyArns``
         * @return {@code this}
         */
        public Builder withManagedPolicyArns(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._managedPolicyArns = value;
            return this;
        }
        /**
         * Sets the value of Path
         * @param value ``AWS::IAM::Group.Path``
         * @return {@code this}
         */
        public Builder withPath(@javax.annotation.Nullable final java.lang.String value) {
            this._path = value;
            return this;
        }
        /**
         * Sets the value of Path
         * @param value ``AWS::IAM::Group.Path``
         * @return {@code this}
         */
        public Builder withPath(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._path = value;
            return this;
        }
        /**
         * Sets the value of Policies
         * @param value ``AWS::IAM::Group.Policies``
         * @return {@code this}
         */
        public Builder withPolicies(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._policies = value;
            return this;
        }
        /**
         * Sets the value of Policies
         * @param value ``AWS::IAM::Group.Policies``
         * @return {@code this}
         */
        public Builder withPolicies(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._policies = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GroupResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public GroupResourceProps build() {
            return new GroupResourceProps() {
                @javax.annotation.Nullable
                private java.lang.Object $groupName = _groupName;
                @javax.annotation.Nullable
                private java.lang.Object $managedPolicyArns = _managedPolicyArns;
                @javax.annotation.Nullable
                private java.lang.Object $path = _path;
                @javax.annotation.Nullable
                private java.lang.Object $policies = _policies;

                @Override
                public java.lang.Object getGroupName() {
                    return this.$groupName;
                }

                @Override
                public void setGroupName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$groupName = value;
                }

                @Override
                public void setGroupName(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$groupName = value;
                }

                @Override
                public java.lang.Object getManagedPolicyArns() {
                    return this.$managedPolicyArns;
                }

                @Override
                public void setManagedPolicyArns(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$managedPolicyArns = value;
                }

                @Override
                public void setManagedPolicyArns(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$managedPolicyArns = value;
                }

                @Override
                public java.lang.Object getPath() {
                    return this.$path;
                }

                @Override
                public void setPath(@javax.annotation.Nullable final java.lang.String value) {
                    this.$path = value;
                }

                @Override
                public void setPath(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$path = value;
                }

                @Override
                public java.lang.Object getPolicies() {
                    return this.$policies;
                }

                @Override
                public void setPolicies(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$policies = value;
                }

                @Override
                public void setPolicies(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$policies = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.iam.cloudformation.GroupResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::IAM::Group.GroupName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getGroupName() {
            return this.jsiiGet("groupName", java.lang.Object.class);
        }

        /**
         * ``AWS::IAM::Group.GroupName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
         */
        @Override
        public void setGroupName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("groupName", value);
        }

        /**
         * ``AWS::IAM::Group.GroupName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-groupname
         */
        @Override
        public void setGroupName(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("groupName", value);
        }

        /**
         * ``AWS::IAM::Group.ManagedPolicyArns``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getManagedPolicyArns() {
            return this.jsiiGet("managedPolicyArns", java.lang.Object.class);
        }

        /**
         * ``AWS::IAM::Group.ManagedPolicyArns``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
         */
        @Override
        public void setManagedPolicyArns(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("managedPolicyArns", value);
        }

        /**
         * ``AWS::IAM::Group.ManagedPolicyArns``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-managepolicyarns
         */
        @Override
        public void setManagedPolicyArns(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("managedPolicyArns", value);
        }

        /**
         * ``AWS::IAM::Group.Path``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getPath() {
            return this.jsiiGet("path", java.lang.Object.class);
        }

        /**
         * ``AWS::IAM::Group.Path``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
         */
        @Override
        public void setPath(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("path", value);
        }

        /**
         * ``AWS::IAM::Group.Path``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-path
         */
        @Override
        public void setPath(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("path", value);
        }

        /**
         * ``AWS::IAM::Group.Policies``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getPolicies() {
            return this.jsiiGet("policies", java.lang.Object.class);
        }

        /**
         * ``AWS::IAM::Group.Policies``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
         */
        @Override
        public void setPolicies(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("policies", value);
        }

        /**
         * ``AWS::IAM::Group.Policies``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html#cfn-iam-group-policies
         */
        @Override
        public void setPolicies(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("policies", value);
        }
    }
}
